@@ -201,7 +201,7 @@ class rsa_decrypt(ApiviewDecorator):
             field_data = rsautils.smart_get_binary_data(field_value)
             plain_data = rsautils.decrypt(field_data, self.private_key)
             plain_text = plain_data.decode("utf-8")
-            view.data[field] = plain_text
+            _django_apiview_request.data[field] = plain_text
         return super().main(_django_apiview_request, func)
 
 
